@@ -18,6 +18,10 @@ with 'Business::Fixflo::Version';
 use Business::Fixflo::Exception;
 use Business::Fixflo::Paginator;
 use Business::Fixflo::Issue;
+use Business::Fixflo::IssueDraft;
+use Business::Fixflo::IssueDraftMedia;
+use Business::Fixflo::Landlord;
+use Business::Fixflo::LandlordProperty;
 use Business::Fixflo::Agency;
 use Business::Fixflo::Property;
 use Business::Fixflo::PropertyAddress;
@@ -129,7 +133,6 @@ sub BUILD {
     }
 }
 
-
 sub _get_issues {
     my ( $self,$params ) = @_;
     my $issues = $self->_api_request( 'GET','Issues' );
@@ -191,6 +194,26 @@ sub _get_properties {
     return $Paginator;
 }
 
+sub _get_landlords {
+    my ( $self,$params ) = @_;
+    my $landlords = $self->_api_request( 'GET','Landlords',$params );
+
+    my $Paginator = Business::Fixflo::Paginator->new(
+        links  => {
+            next     => $landlords->{NextURL},
+            previous => $landlords->{PreviousURL},
+        },
+        client  => $self,
+        class   => 'Business::Fixflo::Landlord',
+        objects => [ map { Business::Fixflo::Landlord->new(
+            client  => $self,
+            %{ $_ },
+        ) } @{ $landlords->{Items} } ],
+    );
+
+    return $Paginator;
+}
+
 sub _get_property_addresses {
     my ( $self,$params ) = @_;
     my $property_addresses = $self->_api_request(
@@ -226,6 +249,32 @@ sub _get_issue {
     return $issue;
 }
 
+sub _get_issue_draft {
+    my ( $self,$id ) = @_;
+
+    my $data = $self->_api_request( 'GET',"IssueDraft/$id" );
+
+    my $issue_draft = Business::Fixflo::IssueDraft->new(
+        client => $self,
+        %{ $data },
+    );
+
+    return $issue_draft;
+}
+
+sub _get_issue_draft_media {
+    my ( $self,$id ) = @_;
+
+    my $data = $self->_api_request( 'GET',"IssueDraftMedia/$id" );
+
+    my $issue_draft_media = Business::Fixflo::IssueDraftMedia->new(
+        client => $self,
+        %{ $data },
+    );
+
+    return $issue_draft_media;
+}
+
 sub _get_agency {
     my ( $self,$id ) = @_;
 
@@ -256,6 +305,36 @@ sub _get_property {
     return $property;
 }
 
+sub _get_landlord {
+    my ( $self,$id,$is_email_address ) = @_;
+
+    my $data = $is_email_address
+        ? $self->_api_request( 'GET',"Landlord?EmailAddress=$id" )
+        : $self->_api_request( 'GET',"Landlord?Id=$id" );
+
+    my $landlord = Business::Fixflo::Landlord->new(
+        client => $self,
+        %{ $data },
+    );
+
+    return $landlord;
+}
+
+sub _get_landlord_property {
+    my ( $self,$id_or_landlord_id,$property_id ) = @_;
+
+    my $data = $property_id
+        ? $self->_api_request( 'GET',"LandlordProperty?LandlordId=$id_or_landlord_id&PropertyId=$property_id" )
+        : $self->_api_request( 'GET',"Landlord?LandlordPropertyId=$id_or_landlord_id" );
+
+    my $property = Business::Fixflo::LandlordProperty->new(
+        client => $self,
+        %{ $data },
+    );
+
+    return $property;
+}
+
 sub _get_property_address {
     my ( $self,$id ) = @_;
 
